<?php
namespace Ak\Test\Constraint;

use PHPUnit\Framework\Constraint\Constraint;

/**
 * Utvrđuje da li konfiguracija sadrži dati ključ.
 *
 * @package Ak\Test\Constraint
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/test
 */
class ConfigHasKey extends Constraint
{
    /** @var string */
    private $key;

    /**
     * Konstruktor.
     *
     * @param string $key
     */
    public function __construct(string $key)
    {
        parent::__construct();
        $this->key = $key;
    }

    /**
     * @param mixed $other
     * @return bool
     */
    protected function matches($other): bool
    {
        $keys = explode('/', $this->key);

        foreach ($keys as $key) {
            if (!array_key_exists($key, $other)) {
                return false;
            }
            $other = $other[$key];
        }

        return true;
    }

    /**
     * @param mixed $other
     * @return string
     */
    protected function failureDescription($other): string
    {
        return 'the configuration ' . $this->toString();
    }

    /**
     * Returns a string representation of the object.
     */
    public function toString(): string
    {
        return 'has the key ' . $this->exporter->export($this->key);
    }
}