<?php
namespace Ak\Test\Constraint;

use PHPUnit\Framework\Constraint\Constraint;

/**
 * Utvrđuje da li dati konfiguracijski array pod datim ključem ima očekivanu vrijednost.
 *
 * @package Ak\Test\Constraint
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/test
 */
class ConfigValueEquals extends Constraint
{
    /** @var string */
    private $key;
    /** @var mixed */
    private $value;

    /**
     * Konstruktor.
     *
     * @param string $key
     * @param mixed $value
     */
    public function __construct(string $key, $value)
    {
        parent::__construct();
        $this->key = $key;
        $this->value = $value;
    }

    /**
     * @param mixed $other
     * @return bool
     */
    protected function matches($other): bool
    {
        $keys = explode('/', $this->key);
        $value = $other;

        foreach ($keys as $key) {
            $value = $value[$key];
        }

        return $value === $this->value;
    }

    /**
     * @param mixed $other
     * @return string
     */
    protected function failureDescription($other): string
    {
        $keys = array_map(function(string $key) {
            return sprintf("['%s']", $key);
        }, explode('/', $this->key));

        return '$config' . implode('', $keys) . ' ' . $this->toString();
    }

    /**
     * Returns a string representation of the object.
     */
    public function toString(): string
    {
        return \sprintf('is equal to "%s"', $this->value);
    }
}