<?php
namespace Ak\Test\Db\Operation;

use Ak\Db\Adapter\Driver\Dbal\Connection as DbalConnection;
use Doctrine\DBAL\Schema\Schema;
use PHPUnit\DbUnit\Database\Connection;
use PHPUnit\DbUnit\DataSet\IDataSet;
use PHPUnit\DbUnit\Operation\Composite as BaseComposite;
use PHPUnit\DbUnit\Operation\Exception;
use PHPUnit\DbUnit\Operation\Operation;

/**
 * Kompozitna operacija.
 *
 * @package Ak\Test\Db\Operation
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/test
 */
class Composite extends BaseComposite
{
    /**
     * Executes the database operation against the given $connection for the
     * given $dataSet.
     *
     * @param Connection $connection
     * @param IDataSet $dataSet *
     * @param DbalConnection|null $dbalConnection
     * @param Schema $schema
     */
    public function execute(Connection $connection, IDataSet $dataSet, DbalConnection $dbalConnection = null, Schema $schema = null): void
    {
        try {
            foreach ($this->operations as $operation) {
                /* @var $operation Operation */
                /** @noinspection PhpMethodParametersCountMismatchInspection */
                $operation->execute($connection, $dataSet, $dbalConnection, $schema);
            }
        } catch (Exception $e) {
            throw new Exception("COMPOSITE[{$e->getOperation()}]", $e->getQuery(), $e->getArgs(), $e->getTable(), $e->getError());
        }
    }
}