<?php
namespace Ak\Test;

use Laminas\Form\ElementInterface;
use Laminas\Form\FormElementManager\FormElementManagerV3Polyfill as FormElementManager;
use Laminas\Form\FormInterface;
use Laminas\ServiceManager\ServiceManager;

/**
 * Alati za testiranje formi i elemenata.
 *
 * @package Ak\Test
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/test
 *
 * @method ServiceManager getContainer(array $config = [], array $services = [])
 */
trait FormTestTrait
{
    /**
     * Vraća form element manager.
     *
     * @return FormElementManager
     */
    protected function getFormElementManager(): FormElementManager
    {
        if (!in_array(\Ak\Form\ConfigProvider::class, $this->configProviders)) {
            $this->configProviders[] = \Ak\Form\ConfigProvider::class;
        }

        $container = $this->getContainer();
        return $container->get('FormElementManager');
    }

    /**
     * Vraća element datog tipa.
     *
     * @param string $type
     * @param array|string $nameOrOptions
     * @return ElementInterface
     */
    protected function getFormElement(string $type, $nameOrOptions = 'element'): ElementInterface
    {
        $formElements = $this->getFormElementManager();
        /** @var ElementInterface $element */
        $element = $formElements->get($type, $nameOrOptions);
        return $element;
    }

    /**
     * Vraća formu s datim imenom.
     *
     * @param string $name
     *
     * @return FormInterface
     */
    protected function getForm(string $name): FormInterface
    {
        /** @var FormInterface $form */
        $form = $this->getFormElement($name, null);
        return $form;
    }
}
