<?php
namespace AkTest\Test;

use Ak\Test\AbstractTestCase;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;

/**
 * Class ConfigTestTrait
 *
 * @package AkTest\Test
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/test
 */
final class ConfigTest extends TestCase
{
    /**
     * @throws \ReflectionException
     */
    public function testWillMergeProvidersFromTestClass()
    {
        /** @var AbstractTestCase|MockObject $test */
        $test = $this->getMockForAbstractClass(AbstractTestCase::class);
        $test->configProviders = [
            TestConfigProvider::class,
        ];

        $config = $test->getConfig();

        $this->assertEquals((new TestConfigProvider())(), $config);
    }

    /**
     * @throws \ReflectionException
     */
    public function testWillMergeGivenConfig()
    {
        /** @var AbstractTestCase|MockObject $test */
        $test = $this->getMockForAbstractClass(AbstractTestCase::class);
        $test->configProviders = [
            TestConfigProvider::class,
        ];

        $config = $test->getConfig([
            'some_component' => [
                'some_param' => 'another value',
            ],
        ]);

        $this->assertArrayHasKey('some_component', $config);
        $this->assertArrayHasKey('some_param', $config['some_component']);
        $this->assertEquals('another value', $config['some_component']['some_param']);
    }

    /**
     * @throws \ReflectionException
     */
    public function testAssertConfigHasKeySupportsPaths()
    {
        /** @var AbstractTestCase|MockObject $test */
        $test = $this->getMockForAbstractClass(AbstractTestCase::class);

        $test->assertConfigHasKey('root/sub_key/param', [
            'root' => [
                'sub_key' => [
                    'param' => 'value',
                ],
            ],
        ]);
    }

    /**
     * @expectedException \PHPUnit\Framework\AssertionFailedError
     * @throws \ReflectionException
     */
    public function testAssertConfigHasKeyFailsWhenNoKey()
    {
        /** @var AbstractTestCase|MockObject $test */
        $test = $this->getMockForAbstractClass(AbstractTestCase::class);

        $test->assertConfigHasKey('key', []);
    }

    /**
     * @expectedException \PHPUnit\Framework\AssertionFailedError
     * @throws \ReflectionException
     */
    public function testAssertConfigValueEqualsFailsWhenNoKey()
    {
        /** @var AbstractTestCase|MockObject $test */
        $test = $this->getMockForAbstractClass(AbstractTestCase::class);

        $test->assertConfigHasKey('key', []);
    }

    /**
     * @expectedException \PHPUnit\Framework\AssertionFailedError
     * @throws \ReflectionException
     */
    public function testAssertConfigValueEqualsFailsWhenValueNotEqual()
    {
        /** @var AbstractTestCase|MockObject $test */
        $test = $this->getMockForAbstractClass(AbstractTestCase::class);

        $test->assertConfigValueEquals('root/param', 'bad value', [
            'root' => [
                'param' => 'value',
            ],
        ]);
    }

    /**
     * @throws \ReflectionException
     */
    public function testAssertConfigValueEqualsCanAssertEquality()
    {
        /** @var AbstractTestCase|MockObject $test */
        $test = $this->getMockForAbstractClass(AbstractTestCase::class);

        $test->assertConfigValueEquals('root/param', 'value', [
            'root' => [
                'param' => 'value',
            ],
        ]);
    }
}