<?php
namespace AkTest\Operation;

use Ak\Test\Db\Operation\CreateSchema;
use AkTest\Test\MockDbTestCase;
use Doctrine\DBAL\Schema\Table;
use PHPUnit\DbUnit\Database\Connection;
use PHPUnit\DbUnit\DataSet\IDataSet;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;

/**
 * Class CreateSchemaTest
 *
 * @package AkTest\Operation
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/test
 */
class CreateSchemaTest extends TestCase
{
    /**
     * @throws \Doctrine\DBAL\DBALException
     */
    public function testCanCreateSchema()
    {
        $test = new MockDbTestCase();

        /** @var Connection|MockObject $connection */
        $connection = $this->createMock(Connection::class);
        /** @var IDataSet|MockObject $dataSet */
        $dataSet = $this->createMock(IDataSet::class);
        $dbalConnection = $test->getDbalConnection();

        $schemaManager = $dbalConnection->getSchemaManager();
        $schema = $schemaManager->createSchema();

        $test->createSchema($schema);

        $operation = new CreateSchema();
        $operation->execute($connection, $dataSet, $dbalConnection, $schema);

        /** @var Table[]|array $tables */
        $tables = $schemaManager->listTables();

        $this->assertCount(1, $tables);
        $this->assertInstanceOf(Table::class, $tables[0]);
        $this->assertEquals('some_table', $tables[0]->getName());
    }

    /**
     * @throws \Doctrine\DBAL\DBALException
     */
    public function testWillNotCreateTablesThatAlreadyExist()
    {
        $test = new MockDbTestCase();

        /** @var Connection|MockObject $connection */
        $connection = $this->createMock(Connection::class);
        /** @var IDataSet|MockObject $dataSet */
        $dataSet = $this->createMock(IDataSet::class);
        $dbalConnection = $test->getDbalConnection();

        $schemaManager = $dbalConnection->getSchemaManager();
        $schema = $schemaManager->createSchema();

        $test->createSchema($schema);

        $operation = new CreateSchema();
        $operation->execute($connection, $dataSet, $dbalConnection, $schema);
        $operation->execute($connection, $dataSet, $dbalConnection, $schema);

        $this->assertTrue(true, 'Nismo bacili exception');
    }
}